@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 3940 2011-01-19 10:28:02Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 4102 2011-05-06 04:20:58Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -19,7 +19,7 @@ require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
 class BaseFrameContainer extends Core
 {
 	protected $_db;	// DB接続オブジェクト
-	const ADMIN_TEMPLATE = '_admin';		// 管理画面用テンプレート
+	//const ADMIN_TEMPLATE = '_admin';		// 管理画面用テンプレート
 	const SYSTEM_TEMPLATE = '_system';		// システム画面用テンプレート
 	const M_ADMIN_TEMPLATE = 'm/_admin';	// 携帯用管理画面テンプレート
 	const ERR_MESSAGE_ACCESS_DENY = 'Access denied.';		// ウィジェットアクセスエラーのメッセージ
@@ -718,7 +718,8 @@ class BaseFrameContainer extends Core
 					$curTemplate = $this->gSystem->defaultSmartphoneTemplateId();		// スマートフォン用デフォルトテンプレート
 				} else if ($pageId == $this->gEnv->getDefaultAdminPageId() ||		// 管理サイトのとき
 							$pageId == $this->gEnv->getDefaultRegistPageId()){		// 登録サイトのとき
-					$curTemplate = '_admin';
+					//$curTemplate = '_admin';
+					$curTemplate = $this->gSystem->defaultAdminTemplateId();
 				} else if (empty($pageId)){			// ページIDが指定されていないときは、ウィジェットを表示しないテンプレートのみの表示
 					// テンプレートIDが指定されている場合はテンプレートを変更
 					$template = $request->trimValueOf(M3_REQUEST_PARAM_TEMPLATE_ID);		// テンプレートIDを取得
@@ -756,7 +757,8 @@ class BaseFrameContainer extends Core
 		
 		if ($curTemplate == ''){
 			// テンプレートが１つもみつからないときは、管理用テンプレートを使用
-			$curTemplate = self::ADMIN_TEMPLATE;
+			//$curTemplate = self::ADMIN_TEMPLATE;
+			$curTemplate = $this->gSystem->defaultAdminTemplateId();
 			echo 'template not found. viewing by administration template. [' . $curTemplate . ']';
 		} else {	// セッションにテンプレートIDを保存
 			// テンプレートIDをセッションに残す場合
@@ -822,7 +824,8 @@ class BaseFrameContainer extends Core
 			$curTemplateId = self::M_ADMIN_TEMPLATE;	// 携帯管理画面用テンプレート
 		} else {			// 携帯以外のサイトへのアクセスの場合
 			if ($type == 1){			// ログインはデフォルトの管理画面テンプレートに固定
-				$curTemplateId = self::ADMIN_TEMPLATE;// 管理用テンプレート
+				//$curTemplateId = self::ADMIN_TEMPLATE;// 管理用テンプレート
+				$curTemplateId = $this->gSystem->defaultAdminTemplateId();
 			} else {
 				$curTemplateId = $this->gSystem->getSystemConfig(self::CONFIG_KEY_MSG_TEMPLATE);
 				if (empty($curTemplateId)){
