@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: accessManager.php 3692 2010-10-11 06:57:09Z fishbone $
+ * @version    SVN: $Id: accessManager.php 4139 2011-05-15 12:36:36Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -73,8 +73,9 @@ class AccessManager extends Core
 		global $gInstanceManager;
 		global $gRequestManager;
 		
-		// 戻り値初期化
+		// 初期化
 		$retValue = false;
+		$now = date("Y/m/d H:i:s");	// 現在日時
 		
 		// アカウントが空のときはアクセス不可
 		if (empty($account)) return false;
@@ -88,7 +89,8 @@ class AccessManager extends Core
 			$pass  = $row['lu_password'];
 			if ($pass == $password){			// パスワード一致のとき
 				// ユーザチェックが必要な場合は承認済みユーザのみ許可する
-				if (($checkUser && $row['lu_user_type'] >= 0 && $row['lu_enable_login']) || // 承認済みユーザ、ログイン可能
+				if (($checkUser && $row['lu_user_type'] >= 0 && $row['lu_enable_login'] &&
+					$this->_isActive($row['lu_active_start_dt'], $row['lu_active_end_dt'], $now)) || // 承認済みユーザ、ログイン可能
 					!$checkUser){			// ユーザのアクセス権をチェックしない場合
 					
 					// ログインした場合はセッションIDを変更する
@@ -125,16 +127,41 @@ class AccessManager extends Core
 		// ログインのログを残す
 		if ($retValue){
 			// ユーザログインログを残す
-			$this->gOpeLog->writeUserInfo(__METHOD__, 'ユーザがログインしました。アカウント: ' . $account, 2100, 'account=' . $account . ', passward=' . $password . ', userid=' . $this->gEnv->getCurrentUserId());
+			$this->gOpeLog->writeUserInfo(__METHOD__, 'ユーザがログインしました。アカウント: ' . $account, 2300,
+											'account=' . $account . ', passward=' . $password . ', userid=' . $this->gEnv->getCurrentUserId(), 'account=' . $account/*検索補助データ*/);
 		} else {
 			// ユーザエラーログを残す
-			$this->gOpeLog->writeUserErr(__METHOD__, 'ユーザがログインに失敗しました。アカウント: ' . $account, 2100, 'account=' . $account . ', passward=' . $password);
+			$this->gOpeLog->writeUserErr(__METHOD__, 'ユーザがログインに失敗しました。アカウント: ' . $account, 2310,
+											'account=' . $account . ', passward=' . $password, 'account=' . $account/*検索補助データ*/);
 			
 			// 入力アカウントを保存
-			$this->db->addErrorLoginLog($account, $accessIp, $this->_accessLogSerialNo);
+			//$this->db->addErrorLoginLog($account, $accessIp, $this->_accessLogSerialNo);
 		}
 		return $retValue;
 	}
+	/**
+	 * 期間から公開可能かチェック
+	 *
+	 * @param timestamp	$startDt		公開開始日時
+	 * @param timestamp	$endDt			公開終了日時
+	 * @param timestamp	$now			基準日時
+	 * @return bool						true=公開可能、false=公開不可
+	 */
+	function _isActive($startDt, $endDt, $now)
+	{
+		$isActive = false;		// 公開状態
+
+		if ($startDt == $this->gEnv->getInitValueOfTimestamp() && $endDt == $this->gEnv->getInitValueOfTimestamp()){
+			$isActive = true;		// 公開状態
+		} else if ($startDt == $this->gEnv->getInitValueOfTimestamp()){
+			if (strtotime($now) < strtotime($endDt)) $isActive = true;		// 公開状態
+		} else if ($endDt == $this->gEnv->getInitValueOfTimestamp()){
+			if (strtotime($now) >= strtotime($startDt)) $isActive = true;		// 公開状態
+		} else {
+			if (strtotime($startDt) <= strtotime($now) && strtotime($now) < strtotime($endDt)) $isActive = true;		// 公開状態
+		}
+		return $isActive;
+	}
 	/**
 	 * ユーザログアウト処理
 	 *
@@ -147,7 +174,8 @@ class AccessManager extends Core
 		
 		// ログアウトログを残す
 		if (!is_null($userInfo)){
-			$this->gOpeLog->writeUserInfo(__METHOD__, 'ユーザがログアウトしました。アカウント: ' . $userInfo->account, 2100, 'account=' . $userInfo->account . ', userid=' . $userInfo->userId);
+			$this->gOpeLog->writeUserInfo(__METHOD__, 'ユーザがログアウトしました。アカウント: ' . $userInfo->account, 2301,
+											'account=' . $userInfo->account . ', userid=' . $userInfo->userId, 'account=' . $userInfo->account/*検索補助データ*/);
 		}
 		
 		// ログアウトしたとき、管理者のセッション値は削除。一般ユーザの場合はログアウトしても残しておくセッション値があるので(テンプレート等)ユーザ情報のみ削除。
