@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_std.sql 4079 2011-04-20 02:57:47Z fishbone $
+-- * @version    SVN: $Id: insert_std.sql 4125 2011-05-09 05:55:32Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -44,13 +44,15 @@ INSERT INTO blog_config
 ('receive_trackback',       '0',         'トラックバックの受け付け',           2),
 ('entry_view_count',        '10',        '記事表示数',                         3),
 ('entry_view_order',        '1',         '記事表示順',                         4),
-('comment_count',           '100',       '1投稿記事のコメント最大数',          5),
-('comment_open_time',       '30',        'コメント投稿可能期間(日)',           6),
-('use_multi_blog',          '0',         'マルチブログを使用',                 7),
-('multi_blog_top_content',  '',          'マルチブログのトップ画面コンテンツ', 8),
-('category_count',          '2',         '記事に設定可能なカテゴリ数',         9),
-('m:entry_view_count',      '3',         '記事表示数(携帯)',                   10),
-('m:entry_view_order',      '1',         '記事表示順(携帯)',                   11);
+('comment_max_length',      '300',       'コメント最大文字数',                 5),
+('comment_count',           '100',       '1投稿記事のコメント最大数',          6),
+('comment_open_time',       '30',        'コメント投稿可能期間(日)',           7),
+('use_multi_blog',          '0',         'マルチブログを使用',                 8),
+('multi_blog_top_content',  '',          'マルチブログのトップ画面コンテンツ', 9),
+('category_count',          '2',         '記事に設定可能なカテゴリ数',         10),
+('m:entry_view_count',      '3',         '記事表示数(携帯)',                   11),
+('m:entry_view_order',      '1',         '記事表示順(携帯)',                   12),
+('m:title_color',           '',         'タイトルの背景色',                    13);
 
 -- BBS設定マスター
 INSERT INTO bbs_config (sf_id,                     sf_value,    sf_name,                        sf_index)
@@ -153,26 +155,28 @@ VALUES                 ('regist_user_completed', 'ja',           'ユーザ自
 -- テンプレート情報
 TRUNCATE TABLE _templates;
 INSERT INTO _templates
-(tm_id,                           tm_name,                         tm_type, tm_device_type, tm_mobile, tm_clean_type, tm_create_dt) VALUES
-('magic3_demo3',                  'magic3_demo3',                  1,       0,              false,     0,             now()),
-('magic3_demo4',                  'magic3_demo4',                  1,       0,              false,     0,             now()),
-('tft0006j_back_to_nature',       'tft0006j_back_to_nature',       1,       0,              false,     1,             now()),
-('pwc007_music',                  'pwc007_music',                  1,       0,              false,     1,             now()),
-('techline_de_template-j15-dog1', 'techline_de_template-j15-dog1', 1,       0,              false,     1,             now()),
-('FishNew',                       'FishNew',                       1,       0,              false,     1,             now()),
-('webstyles_flowers',             'webstyles_flowers',             1,       0,              false,     1,             now()),
-('moyoo_blue_dog',                'moyoo_blue_dog',                1,       0,              false,     0,             now()),
-('moyoo_lane_street',             'moyoo_lane_street',             1,       0,              false,     0,             now()),
-('I_dive',                        'I_dive',                        1,       0,              false,     0,             now()),
-('123wd-j15-3',                   '123wd-j15-3',                   1,       0,              false,     0,             now()),
-('yoga_v1',                       'yoga_v1',                       1,       0,              false,     0,             now()),
-('car_city_v1',                   'car_city_v1',                   1,       0,              false,     0,             now()),
-('art26_test1',                   'art26_test1',                   1,       0,              false,     0,             now()),
-('art26_test2',                   'art26_test2',                   1,       0,              false,     0,             now()),
-('art30rc1_sample1',              'art30rc1_sample1',              1,       0,              false,     0,             now()),
-('m/default',                     'm/default',                     0,       1,              true,      0,             now()),
-('m/smallfont',                   'm/smallfont',                   0,       1,              true,      0,             now()),
-('s/default',                     's/default',                     1,       2,              false,     0,             now());
+(tm_id,                           tm_name,                         tm_type, tm_device_type, tm_mobile, tm_available, tm_clean_type, tm_create_dt) VALUES
+('_admin2',                       '_admin2',                       1,       0,              false,     false,        0,             now()),
+('_system',                       '_system',                       1,       0,              false,     false,        0,             now()),
+('magic3_demo3',                  'magic3_demo3',                  1,       0,              false,     true,         0,             now()),
+('magic3_demo4',                  'magic3_demo4',                  1,       0,              false,     true,         0,             now()),
+('tft0006j_back_to_nature',       'tft0006j_back_to_nature',       1,       0,              false,     true,         1,             now()),
+('pwc007_music',                  'pwc007_music',                  1,       0,              false,     true,         1,             now()),
+('techline_de_template-j15-dog1', 'techline_de_template-j15-dog1', 1,       0,              false,     true,         1,             now()),
+('FishNew',                       'FishNew',                       1,       0,              false,     true,         1,             now()),
+('webstyles_flowers',             'webstyles_flowers',             1,       0,              false,     true,         1,             now()),
+('moyoo_blue_dog',                'moyoo_blue_dog',                1,       0,              false,     true,         0,             now()),
+('moyoo_lane_street',             'moyoo_lane_street',             1,       0,              false,     true,         0,             now()),
+('I_dive',                        'I_dive',                        1,       0,              false,     true,         0,             now()),
+('123wd-j15-3',                   '123wd-j15-3',                   1,       0,              false,     true,         0,             now()),
+('yoga_v1',                       'yoga_v1',                       1,       0,              false,     true,         0,             now()),
+('car_city_v1',                   'car_city_v1',                   1,       0,              false,     true,         0,             now()),
+('art26_test1',                   'art26_test1',                   1,       0,              false,     true,         0,             now()),
+('art26_test2',                   'art26_test2',                   1,       0,              false,     true,         0,             now()),
+('art30rc1_sample1',              'art30rc1_sample1',              1,       0,              false,     true,         0,             now()),
+('m/default',                     'm/default',                     0,       1,              true,      true,         0,             now()),
+('m/smallfont',                   'm/smallfont',                   0,       1,              true,      true,         0,             now()),
+('s/default',                     's/default',                     1,       2,              false,     true,         0,             now());
 
 -- メニューIDマスター
 INSERT INTO _menu_id
@@ -293,6 +297,22 @@ INSERT INTO mblog_config
 ('top_contents',           '',                     'トップ画面のコンテンツ'),
 ('m:top_contents',           '',                   'トップ画面のコンテンツ(携帯)');
 
+-- --------------------------------------------------------------------------------------------------
+-- イベント情報用
+-- --------------------------------------------------------------------------------------------------
+-- イベント設定マスター
+INSERT INTO event_config
+(eg_id,                     eg_value,    eg_name,                              eg_index) VALUES
+('receive_comment',         '0',         'コメントの受け付け',                 1),
+('entry_view_count',        '10',        '記事表示数',                         2),
+('entry_view_order',        '0',         '記事表示順',                         3),
+('comment_count',           '100',       '1投稿記事のコメント最大数',          4),
+('comment_open_time',       '30',        'コメント投稿可能期間(日)',           5),
+('top_contents',            '',          'トップ画面コンテンツ',               6),
+('m:entry_view_count',      '3',         '記事表示数(携帯)',                   7),
+('m:entry_view_order',      '1',         '記事表示順(携帯)',                   8),
+('m:top_contents',          '',          'トップ画面コンテンツ(携帯)',         9);
+
 -- --------------------------------------------------------------------------------------------------
 -- 携帯クイズ王ウィジェット用
 -- --------------------------------------------------------------------------------------------------
