@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainAdjustwidgetWidgetContainer.php 4002 2011-02-19 07:47:55Z fishbone $
+ * @version    SVN: $Id: admin_mainAdjustwidgetWidgetContainer.php 4150 2011-05-24 07:06:49Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -39,10 +39,24 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$this->db = new admin_mainDb();
 		
 		// 表示位置
-		$this->itemAlignArray = array(	array(	'name' => '指定なし',	'value' => ''),
-										array(	'name' => '左寄せ',	'value' => 'left'),
-										array(	'name' => '中央',	'value' => 'center'),
-										array(	'name' => '右寄せ',	'value' => 'right'));
+		$this->itemAlignArray = array(	array(	'name' => $this->_('Not selected'),	'value' => ''),		// 指定なし
+										array(	'name' => $this->_('Left'),			'value' => 'left'),		// 左寄せ
+										array(	'name' => $this->_('Center'),		'value' => 'center'),	// 中央
+										array(	'name' => $this->_('Right'),		'value' => 'right'));	// 右寄せ
+	}
+	/**
+	 * ヘルプデータを設定
+	 *
+	 * ヘルプの設定を行う場合はヘルプIDを返す。
+	 * ヘルプデータの読み込むディレクトリは「自ウィジェットディレクトリ/include/help」に固定。
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
+	 * @return string 						ヘルプID。ヘルプデータはファイル名「help_[ヘルプID].php」で作成。ヘルプを使用しない場合は空文字列「''」を返す。
+	 */
+	function _setHelp($request, &$param)
+	{	
+		return 'adjustwidget';
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -128,11 +142,11 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$replaceNew = false;		// データを再取得するかどうか
 		if ($act == 'update'){		// 行更新のとき
 			// 入力チェック
-			$this->checkNumeric($marginTop, 'マージン(上)', true);
-			$this->checkNumeric($marginBottom, 'マージン(下)', true);
-			$this->checkNumeric($marginLeft, 'マージン(左)', true);
-			$this->checkNumeric($marginRight, 'マージン(右)', true);
-			$this->checkInput($widgetId, 'ウィジェットID');
+			$this->checkNumeric($marginTop, $this->_('Margin Top'), true);		// マージン(上)
+			$this->checkNumeric($marginBottom, $this->_('Margin Bottom'), true);		// マージン(下)
+			$this->checkNumeric($marginLeft, $this->_('Margin Left'), true);		// マージン(左)
+			$this->checkNumeric($marginRight, $this->_('Margin Right'), true);		// マージン(右)
+			$this->checkInput($widgetId, $this->_('Widget ID'));		// ウィジェットID
 			
 			// エラーなしの場合は、データを更新
 			if ($this->getMsgCount() == 0){
@@ -146,7 +160,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				
 				$ret = $this->db->updatePageDefInfo($defSerial, $style, $title, $titleVisible, $useRender);
 				if ($ret){		// データ追加成功のとき
-					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
+					$this->setMsg(self::MSG_GUIDANCE, $this->_('Configration updated.'));		// データを更新しました
 					$replaceNew = true;			// データを再取得
 					
 					// キャッシュをクリア
@@ -155,13 +169,13 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 					// 親ウィンドウを更新
 					$this->gPage->updateParentWindow($defSerial);
 				} else {
-					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
+					$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in updating configration.'));			// データ更新に失敗しました
 				}
 			}
 		} else if ($act == 'update_other'){		// 「その他」更新のとき
 			// 期間範囲のチェック
 			if (!empty($start_date) && !empty($end_date)){
-				if (strtotime($start_date . ' ' . $start_time) >= strtotime($end_date . ' ' . $end_time)) $this->setUserErrorMsg('公開期間が不正です');
+				if (strtotime($start_date . ' ' . $start_time) >= strtotime($end_date . ' ' . $end_time)) $this->setUserErrorMsg($this->_('Invalid view term.'));		// 表示期間が不正です
 			}
 			
 			// エラーなしの場合は、データを更新
@@ -194,7 +208,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				if ($ret) $ret = $this->db->toggleSharedWidget($pageId, $pageSubId, $defSerial, $shared);
 				
 				if ($ret){		// データ追加成功のとき
-					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
+					$this->setMsg(self::MSG_GUIDANCE, $this->_('Configration updated.'));		// データを更新しました
 					$replaceNew = true;			// データを再取得
 					
 					// キャッシュをクリア
@@ -203,7 +217,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 					// 親ウィンドウを更新
 					$this->gPage->updateParentWindow($defSerial);
 				} else {
-					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
+					$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in updating configration.'));		// データ更新に失敗しました
 				}
 			}
 			// タブを選択
@@ -320,6 +334,9 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		// パス等を設定
 		$this->tmpl->addVar('_widget', 'calendar_img', $this->getUrl($this->gEnv->getRootUrl() . self::CALENDAR_ICON_FILE));	// カレンダーアイコン
 		
+		// テキストをローカライズ
+		$this->localizeText();
+		
 		// ページ定義IDとページ定義のレコードシリアル番号を更新
 		$this->endPageDefParam($defSerial, $defConfigId, $this->paramObj);
 	}
@@ -401,5 +418,45 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 			$this->tmpl->parseTemplate('sub_id_list', 'a');
 		}
 	}
+	/**
+	 * テキストをローカライズ
+	 *
+	 * @return なし
+	 */
+	function localizeText()
+	{
+		$localeText = array();
+		$localeText['msg_update'] = $this->_('Update config?');		// 設定を更新しますか?
+		$localeText['label_widget_common_config'] = $this->_('Widget Common Config');			// ウィジェット共通設定
+		$localeText['label_config_basic'] = $this->_('Basic');			// 基本
+		$localeText['label_config_other'] = $this->_('Others');			// その他
+		$localeText['label_adjust_widget'] = $this->_('Adjust Widget Title and Contents');			// ウィジェットタイトル、位置調整
+		$localeText['label_title'] = $this->_('Title');			// タイトル名
+		$localeText['label_visible'] = $this->_('Visible');			// 表示
+		$localeText['label_margin'] = $this->_('Margin');			// マージン
+		$localeText['label_top'] = $this->_('Top:');			// 上：
+		$localeText['label_bottom'] = $this->_('Bottom:');			// 下：
+		$localeText['label_left'] = $this->_('Left:');			// 左：
+		$localeText['label_right'] = $this->_('Right:');			// 右：
+		$localeText['label_position'] = $this->_('Contents Position');			// テキスト表示位置
+		$localeText['label_render'] = $this->_('Render');// 描画処理
+		$localeText['label_use_joomla_render'] = $this->_('Render by Joomla! style');// Joomla!スタイルの描画処理を使用
+		$localeText['label_view_control'] = $this->_('View Control');// 表示制御
+		$localeText['label_shared_attr'] = $this->_('Page Shared Attribute');// ページ共通属性
+		$localeText['label_on'] = $this->_('On');// オン
+		$localeText['label_view_term'] = $this->_('View Term');// 表示期間
+		$localeText['label_except_page'] = $this->_('Except Page');		// 例外ページ
+		$localeText['label_start_date'] = $this->_('Start Date:');		// 開始日
+		$localeText['label_end_date'] = $this->_('End Date:');		// 終了日
+		$localeText['label_hour'] = $this->_('Hour:');		// 時間
+		$localeText['label_calendar'] = $this->_('Calendar');		// カレンダー
+		$localeText['label_view_option'] = $this->_('View Option');		// 表示オプション
+		$localeText['label_view_type'] = $this->_('View Type');		// 表示表示タイプ
+		$localeText['label_always'] = $this->_('Always');		// 常時表示
+		$localeText['label_login'] = $this->_('When user in login');		// ログイン時のみ表示
+		$localeText['label_no_login'] = $this->_('When user not in login');		// 非ログイン時のみ表示
+		$localeText['label_update'] = $this->_('Update');// 更新
+		$this->setLocaleText($localeText);
+	}
 }
 ?>
