@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainUserlistWidgetContainer.php 3582 2010-09-11 10:37:32Z fishbone $
+ * @version    SVN: $Id: admin_mainUserlistWidgetContainer.php 4140 2011-05-16 14:21:08Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -28,7 +28,10 @@ class admin_mainUserlistWidgetContainer extends admin_mainBaseWidgetContainer
 	private $userType;		// ユーザタイプ
 	const DEFAULT_LIST_COUNT = 30;			// 最大リスト表示数
 	const DEFAULT_PASSWORD = '********';	// 設定済みを示すパスワード
-		
+	const CALENDAR_ICON_FILE = '/images/system/calendar.png';		// カレンダーアイコン
+	const ACTIVE_ICON_FILE = '/images/system/active.png';			// 公開中アイコン
+	const INACTIVE_ICON_FILE = '/images/system/inactive.png';		// 非公開アイコン
+	
 	/**
 	 * コンストラクタ
 	 */
@@ -171,7 +174,26 @@ class admin_mainUserlistWidgetContainer extends admin_mainBaseWidgetContainer
 		$password = $request->trimValueOf('password');
 		$this->userType = $request->trimValueOf('item_usertype');		// ユーザ種別
 		$canLogin = ($request->trimValueOf('item_canlogin') == 'on') ? 1 : 0;		// ログインできるかどうか
-
+		$start_date = $request->trimValueOf('item_start_date');		// 公開期間開始日付
+		if (!empty($start_date)) $start_date = $this->convertToProperDate($start_date);
+		$start_time = $request->trimValueOf('item_start_time');		// 公開期間開始時間
+		if (empty($start_date)){
+			$start_time = '';					// 日付が空のときは時刻も空に設定する
+		} else {
+			if (empty($start_time)) $start_time = '00:00';		// 日付が入っているときは時間にデフォルト値を設定
+		}
+		if (!empty($start_time)) $start_time = $this->convertToProperTime($start_time, 1/*時分フォーマット*/);
+		
+		$end_date = $request->trimValueOf('item_end_date');		// 公開期間終了日付
+		if (!empty($end_date)) $end_date = $this->convertToProperDate($end_date);
+		$end_time = $request->trimValueOf('item_end_time');		// 公開期間終了時間
+		if (empty($end_date)){
+			$end_time = '';					// 日付が空のときは時刻も空に設定する
+		} else {
+			if (empty($end_time)) $end_time = '00:00';		// 日付が入っているときは時間にデフォルト値を設定
+		}
+		if (!empty($end_time)) $end_time = $this->convertToProperTime($end_time, 1/*時分フォーマット*/);
+		
 		$isAdmin = false;			// 管理権限ありかどうか
 		$limitedMenu = false;		// ユーザタイプメニューの項目を制限するかどうか
 		$reloadData = false;		// データの再読み込み
@@ -181,6 +203,11 @@ class admin_mainUserlistWidgetContainer extends admin_mainBaseWidgetContainer
 			//$this->checkSingleByte($account, 'アカウント');
 			$this->checkInput($account, 'アカウント');
 			
+			// 期間範囲のチェック
+			if (!empty($start_date) && !empty($end_date)){
+				if (strtotime($start_date . ' ' . $start_time) >= strtotime($end_date . ' ' . $end_time)) $this->setUserErrorMsg('有効期間が不正です');
+			}
+			
 			// アカウント重複チェック
 			// 設定データを取得
 			$ret = $this->db->getUserBySerial($this->serialNo, $row);
@@ -201,7 +228,23 @@ class admin_mainUserlistWidgetContainer extends admin_mainBaseWidgetContainer
 				// ユーザ種別が負のときはログイン不可
 				if (intval($this->userType) < 0) $canLogin = 0;
 				
-				$ret = $this->db->updateUser($this->serialNo, $name, $account, $password, $this->userType, $canLogin, $newSerial);
+				// 保存データ作成
+				if (empty($start_date)){
+					$startDt = $this->gEnv->getInitValueOfTimestamp();
+				} else {
+					$startDt = $start_date . ' ' . $start_time;
+				}
+				if (empty($end_date)){
+					$endDt = $this->gEnv->getInitValueOfTimestamp();
+				} else {
+					$endDt = $end_date . ' ' . $end_time;
+				}
+				if ($this->userType == UserInfo::USER_TYPE_SYS_ADMIN){		// システム管理者は有効期間の設定不可
+					$startDt = $this->gEnv->getInitValueOfTimestamp();
+					$endDt = $this->gEnv->getInitValueOfTimestamp();
+				}
+				
+				$ret = $this->db->updateUser($this->serialNo, $name, $account, $password, $this->userType, $canLogin, $startDt, $endDt, $newSerial);
 				if ($ret){		// データ追加成功のとき
 					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 					$this->serialNo = $newSerial;
@@ -216,7 +259,12 @@ class admin_mainUserlistWidgetContainer extends admin_mainBaseWidgetContainer
 			//$this->checkSingleByte($account, 'アカウント');
 			$this->checkInput($account, 'アカウント');
 			if ($this->userType == '') $this->setUserErrorMsg('ユーザ種別が選択されていません');
-
+			
+			// 期間範囲のチェック
+			if (!empty($start_date) && !empty($end_date)){
+				if (strtotime($start_date . ' ' . $start_time) >= strtotime($end_date . ' ' . $end_time)) $this->setUserErrorMsg('有効期間が不正です');
+			}
+			
 			// アカウント重複チェック
 			if ($this->sysDb->isExistsAccount($account)) $this->setMsg(self::MSG_USER_ERR, 'アカウントが重複しています');
 						
@@ -228,7 +276,23 @@ class admin_mainUserlistWidgetContainer extends admin_mainBaseWidgetContainer
 				// ユーザ種別が負のときはログイン不可
 				if (intval($this->userType) < 0) $canLogin = 0;
 				
-				$ret = $this->db->addNewUser($name, $account, $password, $this->userType, $canLogin, $newSerial);
+				// 保存データ作成
+				if (empty($start_date)){
+					$startDt = $this->gEnv->getInitValueOfTimestamp();
+				} else {
+					$startDt = $start_date . ' ' . $start_time;
+				}
+				if (empty($end_date)){
+					$endDt = $this->gEnv->getInitValueOfTimestamp();
+				} else {
+					$endDt = $end_date . ' ' . $end_time;
+				}
+				if ($this->userType == UserInfo::USER_TYPE_SYS_ADMIN){		// システム管理者は有効期間の設定不可
+					$startDt = $this->gEnv->getInitValueOfTimestamp();
+					$endDt = $this->gEnv->getInitValueOfTimestamp();
+				}
+				
+				$ret = $this->db->addNewUser($name, $account, $password, $this->userType, $canLogin, $startDt, $endDt, $newSerial);
 				if ($ret){		// データ追加成功のとき
 					$this->setMsg(self::MSG_GUIDANCE, 'データを追加しました');
 					$this->serialNo = $newSerial;
@@ -245,7 +309,9 @@ class admin_mainUserlistWidgetContainer extends admin_mainBaseWidgetContainer
 				$this->setMsg(self::MSG_APP_ERR, 'データ削除に失敗しました');
 			}
 		} else {
-			if (!empty($this->serialNo)) $reloadData = true;		// データの再読み込み
+			// 初期値を設定
+			$canLogin = 1;		// ログインできるかどうか
+			$reloadData = true;		// データの再読み込み
 		}
 		if ($reloadData){		// データの再読み込み
 			// 設定データを取得
@@ -261,6 +327,10 @@ class admin_mainUserlistWidgetContainer extends admin_mainBaseWidgetContainer
 				}
 				$canLogin = $row['lu_enable_login'];		// ログインできるかどうか
 				$loginUserId = $row['lu_id'];				// ユーザID
+				$start_date = $this->convertToDispDate($row['lu_active_start_dt']);	// 有効期間開始日
+				$start_time = $this->convertToDispTime($row['lu_active_start_dt'], 1/*時分*/);	// 有効期間開始時間
+				$end_date = $this->convertToDispDate($row['lu_active_end_dt']);	// 有効期間終了日
+				$end_time = $this->convertToDispTime($row['lu_active_end_dt'], 1/*時分*/);	// 有効期間終了時間
 			}
 		}
 		// ユーザタイプ選択メニュー作成
@@ -274,7 +344,12 @@ class admin_mainUserlistWidgetContainer extends admin_mainBaseWidgetContainer
 		if ($canLogin) $canLoginCheck = 'checked';
 		$this->tmpl->addVar("_widget", "can_login", $canLoginCheck);
 		$this->tmpl->addVar("_widget", "userid", $loginUserId);// ユーザID
-				
+		$this->tmpl->addVar('_widget', 'calendar_img', $this->getUrl($this->gEnv->getRootUrl() . self::CALENDAR_ICON_FILE));	// カレンダーアイコン
+		$this->tmpl->addVar("_widget", "start_date", $start_date);	// 有効期間開始日
+		$this->tmpl->addVar("_widget", "start_time", $start_time);	// 有効期間開始時間
+		$this->tmpl->addVar("_widget", "end_date", $end_date);	// 有効期間終了日
+		$this->tmpl->addVar("_widget", "end_time", $end_time);	// 有効期間終了時間
+		
 		if (empty($this->serialNo)){		// ユーザIDが空のときは新規とする
 			$this->tmpl->setAttribute('add_button', 'visibility', 'visible');// 新規登録ボタン表示
 		} else {
@@ -330,6 +405,14 @@ class admin_mainUserlistWidgetContainer extends admin_mainBaseWidgetContainer
 				$userType = '該当なし';
 				break;
 		}
+		
+		// ログイン回数
+		$loginCount = $fetchedRow['ll_login_count'];
+		if (empty($loginCount)) $loginCount = '0';
+
+		// ログイン状況画面URL
+		$loginStatusUrl = '?task=loginstatus_history&account=' . $fetchedRow['lu_account'];
+		
 		$row = array(
 			'index' => $index,													// 行番号
 			'serial' => $this->convertToDispString($fetchedRow['lu_serial']),			// シリアル番号
@@ -340,6 +423,8 @@ class admin_mainUserlistWidgetContainer extends admin_mainBaseWidgetContainer
 			'update_dt' => $this->convertToDispDateTime($fetchedRow['lu_create_dt']),	// 更新日時
 			'is_admin' => $isAdmin,													// 管理者権限があるかどうか
 			'can_login' => $canLogin,												// ログイン可能かどうか
+			'login_count' => $loginCount,			// ログイン回数
+			'login_status_url' => $this->convertUrlToHtmlEntity($loginStatusUrl),	// ログイン状況画面URL
 			'selected' => $selected												// 項目選択用ラジオボタン
 		);
 		$this->tmpl->addVars('userlist', $row);
