@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 4140 2011-05-16 14:21:08Z fishbone $
+ * @version    SVN: $Id: index.php 4149 2011-05-23 14:05:10Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -330,20 +330,6 @@ $HELP['menuid_del_btn']['body'] = '選択されているメニューIDを削除
 $HELP['menuid_ret_btn']['title'] = '戻るボタン';
 $HELP['menuid_ret_btn']['body'] = 'メニューID一覧へ戻ります。';
 
-// ########## ウィジェット表示調整 ##########
-$HELP['adjustwidget']['title'] = 'ウィジェットタイトル、位置調整';
-$HELP['adjustwidget']['body'] = 'ウィジェットのタイトルやウィジェットの表示内容の位置調整を行います。';
-$HELP['adjustwidget_view']['title'] = '表示設定';
-$HELP['adjustwidget_view']['body'] = 'ウィジェットの表示制御を行います。';
-$HELP['adjustwidget_title']['title'] = 'タイトル名';
-$HELP['adjustwidget_title']['body'] = 'ウィジェットの上部に表示されるタイトル名を設定します。空に設定した場合はデフォルトのタイトル名が表示されます。「表示」チェックボックスでタイトルの表示、非表示の制御を行います。ここでの設定は他のすべての設定に優先します。';
-$HELP['adjustwidget_align']['title'] = 'テキスト表示位置';
-$HELP['adjustwidget_align']['body'] = 'ウィジェットの表示内容のテキストの位置を設定します。';
-$HELP['adjustwidget_margin']['title'] = 'マージン';
-$HELP['adjustwidget_margin']['body'] = 'ウィジェットの表示内容のマージンを設定します。空に設定したフィールドは指定なしになります。';
-$HELP['adjustwidget_render']['title'] = '描画処理';
-$HELP['adjustwidget_render']['body'] = '「Joomla!スタイルの描画処理」をオンにするとウィジェットの周囲の枠やタイトルが付加されます。チェックをはずした場合はウィジェットのプレーンな出力が表示されます。';
-
 // ########## テナントサーバ管理 ##########
 $HELP['tenantserver']['title'] = 'テナントサーバ管理';
 $HELP['tenantserver']['body'] = 'テナントサーバの管理を行います';
