@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_menu3WidgetContainer.php 3930 2011-01-11 05:54:05Z fishbone $
+ * @version    SVN: $Id: admin_menu3WidgetContainer.php 4132 2011-05-12 11:36:55Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -29,6 +29,7 @@ class admin_menu3WidgetContainer extends BaseAdminWidgetContainer
 	const THEME_CSS_FILE = 'jquery-ui.custom.css';		// テーマファイル
 //	const CF_ADMIN_DEFAULT_THEME = 'admin_default_theme';		// 管理画面用jQueryUIテーマ
 	const HELP_ICON_FILE = '/images/system/help24.gif';		// ヘルプアイコン
+	const MAX_SITENAME_LENGTH = 10;		// サイト名の最大文字数
 	const ICON_SIZE = 24;			// アイコンサイズ
 	const HELP_TITLE = 'ヘルプ';
 	
@@ -203,8 +204,8 @@ class admin_menu3WidgetContainer extends BaseAdminWidgetContainer
 			
 			// サイト表示
 			$siteName = $this->gEnv->getSiteName();
-			//if (empty($siteName)) $siteName = self::DEFAULT_SITE_NAME;
 			if (empty($siteName)) $siteName = $this->_('Untitled Site');
+			$siteName = makeTruncStr($siteName, self::MAX_SITENAME_LENGTH);
 			$siteUrl = $this->gEnv->getRootUrl();
 			$this->tmpl->addVar("menu", "site_name", $siteName);
 			$this->tmpl->addVar("menu", "pc_url", $siteUrl);
