@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 4046 2011-03-25 10:43:16Z fishbone $
+ * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 4064 2011-04-08 08:49:26Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_default_contentBaseWidgetContainer.php');
@@ -141,6 +141,18 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 				}
 			}
 			if (count($delItems) > 0){
+				// 削除するコンテンツの情報を取得
+				$delContentInfo = array();
+				for ($i = 0; $i < count($delItems); $i++){
+					$ret = $this->db->getContentBySerial($delItems[$i], $row);
+					if ($ret){
+						$newInfoObj = new stdClass;
+						$newInfoObj->contentId = $row['cn_id'];		// コンテンツID
+						$newInfoObj->name = $row['cn_name'];		// コンテンツ名前
+						$delContentInfo[] = $newInfoObj;
+					}
+				}
+				
 				$ret = $this->db->delContentItem($delItems);
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
@@ -149,6 +161,12 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 					for ($i = 0; $i < count($delItems); $i++){
 						$this->clearCacheBySerial($delItems[$i]);
 					}
+					
+					// 運用ログを残す
+					for ($i = 0; $i < count($delContentInfo); $i++){
+						$infoObj = $delContentInfo[$i];
+						$this->gOpeLog->writeUserInfo(__METHOD__, '汎用コンテンツ(PC)を削除しました。ID: ' . $infoObj->contentId, 2100, 'タイトル=' . $infoObj->name);
+					}
 				} else {
 					$this->setAppErrorMsg('データ削除に失敗しました');
 				}
@@ -250,6 +268,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 		if (!empty($end_time)) $end_time = $this->convertToProperTime($end_time, 1/*時分フォーマット*/);
 		
 		$reloadData = false;		// データの再読み込み
+		$histryIndex = -1;	// 履歴番号
 		if ($act == 'add'){		// 項目追加の場合
 			// 入力チェック
 			$this->checkInput($name, '名前');
@@ -283,6 +302,14 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 					// コンテンツ更新情報をサーバへ登録
 					$ret = $this->registContentInfoBySerial($this->serialNo, true/*新規*/);
 					if ($ret) $this->setGuidanceMsg('更新情報をサーバへアップしました');
+					
+					// 運用ログを残す
+					$ret = $this->db->getContentBySerial($this->serialNo, $row);
+					if ($ret){
+						$contentId = $row['cn_id'];		// コンテンツID
+						$name = $row['cn_name'];		// コンテンツ名前
+					}
+					$this->gOpeLog->writeUserInfo(__METHOD__, '汎用コンテンツ(PC)を追加しました。ID: ' . $contentId, 2100, 'タイトル=' . $name);
 				} else {
 					$this->setAppErrorMsg('データ追加に失敗しました');
 				}
@@ -326,6 +353,14 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 					// コンテンツ更新情報をサーバへ登録
 					$ret = $this->registContentInfoBySerial($this->serialNo);
 					if ($ret) $this->setGuidanceMsg('更新情報をサーバへアップしました');
+					
+					// 運用ログを残す
+					$ret = $this->db->getContentBySerial($this->serialNo, $row);
+					if ($ret){
+						$contentId = $row['cn_id'];		// コンテンツID
+						$name = $row['cn_name'];		// コンテンツ名前
+					}
+					$this->gOpeLog->writeUserInfo(__METHOD__, '汎用コンテンツ(PC)を更新しました。ID: ' . $contentId, 2100, 'タイトル=' . $name);
 				} else {
 					$this->setAppErrorMsg('データ更新に失敗しました');
 				}
@@ -336,6 +371,13 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 			}
 			// エラーなしの場合は、データを削除
 			if ($this->getMsgCount() == 0){
+				// 削除するコンテンツの情報を取得
+				$ret = $this->db->getContentBySerial($this->serialNo, $row);
+				if ($ret){
+					$contentId = $row['cn_id'];		// コンテンツID
+					$name = $row['cn_name'];		// コンテンツ名前
+				}
+					
 				$ret = $this->db->delContentItem(array($this->serialNo));
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
@@ -346,10 +388,15 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 					
 					// 親ウィンドウを更新
 					$this->gPage->updateParentWindow();
+					
+					// 運用ログを残す
+					$this->gOpeLog->writeUserInfo(__METHOD__, '汎用コンテンツ(PC)を削除しました。ID: ' . $contentId, 2100, 'タイトル=' . $name);
 				} else {
 					$this->setAppErrorMsg('データ削除に失敗しました');
 				}
 			}
+		} else if ($act == 'get_history'){		// 履歴データの取得のとき
+			$reloadData = true;		// データの再読み込み
 		} else {
 			// コンテンツIDが設定されているとき(他ウィジェットからの表示)は、データを取得
 			$contentId = $request->trimValueOf('contentid');		// コンテンツID
@@ -391,6 +438,9 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 				$start_time = $this->convertToDispTime($row['cn_active_start_dt'], 1/*時分*/);	// 公開期間開始時間
 				$end_date = $this->convertToDispDate($row['cn_active_end_dt']);	// 公開期間終了日
 				$end_time = $this->convertToDispTime($row['cn_active_end_dt'], 1/*時分*/);	// 公開期間終了時間
+				
+				// 履歴番号
+				if ($row['cn_deleted']) $histryIndex = $row['cn_history_index'];
 			} else {
 				$this->serialNo = 0;
 			}
@@ -426,7 +476,9 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 			
 		// パスの設定
 		$this->tmpl->addVar('_widget', 'admin_url', $this->getUrl($this->gEnv->getDefaultAdminUrl()));// 管理者URL
-		$previewUrl = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_CONTENT_ID . '=' . $contentId . '&' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_PREVIEW;
+		$previewUrl = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_CONTENT_ID . '=' . $contentId;
+		if ($histryIndex >= 0) $previewUrl .= '&' . M3_REQUEST_PARAM_HISTORY . '=' . $histryIndex;
+		$previewUrl .= '&' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_PREVIEW;
 		$this->tmpl->addVar('_widget', 'preview_url', $previewUrl);// プレビュー用URL(一般画面)
 		$this->tmpl->addVar('_widget', 'custom_value_task', 'usercustom');		// ユーザ定義値参照用
 		$this->tmpl->addVar('_widget', 'admin_widget_id', self::ADMIN_WIDGET_ID);// ユーザ定義値参照用(管理ウィジェットのウィジェットID)
@@ -434,11 +486,18 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 		
 		// ボタンの表示制御
 		if (empty($this->serialNo)){		// 新規追加項目を選択しているとき
-			$this->tmpl->addVar("_widget", "sel_item_id", '新規');			// コンテンツID
+			$this->tmpl->addVar("_widget", "sel_item_id", '');			// コンテンツID
+			$this->tmpl->addVar("_widget", "item_id", '新規');			// コンテンツID
 			$this->tmpl->setAttribute('add_button', 'visibility', 'visible');// 「新規追加」ボタン
 			$this->tmpl->addVar('_widget', 'preview_btn_disabled', 'disabled');// プレビューボタン使用不可
+			$this->tmpl->addVar('_widget', 'history_btn_disabled', 'disabled');// 履歴ボタン使用不可
 		} else {
+			// 履歴番号
+			$itemId = $contentId;			// コンテンツID
+			if ($histryIndex >= 0) $itemId .= '(' . ($histryIndex +1) . ')';
+
 			$this->tmpl->addVar("_widget", "sel_item_id", $contentId);			// コンテンツID
+			$this->tmpl->addVar("_widget", "item_id", $itemId);			// コンテンツID
 			$this->tmpl->setAttribute('del_button', 'visibility', 'visible');// 「削除」ボタン
 		}
 		// 「戻る」ボタンの表示
