@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: reg_userWidgetContainer.php 2266 2009-08-28 08:25:59Z fishbone $
+ * @version    SVN: $Id: reg_userWidgetContainer.php 2938 2010-03-17 14:20:25Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -48,7 +48,7 @@ class reg_userWidgetContainer extends BaseWidgetContainer
 			case 'changepwd':		// パスワード変更
 				// ログイン状態を取得
 				if (!$this->gEnv->isCurrentUserLogined()){		// ログインされていない場合
-					$this->SetMsg(0, "ログインが必要です");
+					$this->SetMsg(self::MSG_APP_ERR, "ログインが必要です");
 					return true;
 				}
 		}
@@ -62,7 +62,7 @@ class reg_userWidgetContainer extends BaseWidgetContainer
 				$this->gLaunch->goSubWidget($task);
 				return false;
 			default:
-				$this->SetMsg(0, "画面が見つかりません");
+				$this->SetMsg(self::MSG_APP_ERR, "画面が見つかりません");
 				return true;
 		}
 	}
